@@ -1,6 +1,8 @@
 from tokenizer_tools.conll.reader import read_conll
+import pytest
 
 
+@pytest.mark.skip("")
 def test_read_conll(datadir):
     result = read_conll(datadir / "data.conll")
 
